/* ----------------------------------------------------- */
/* Clipboard Viewer                                      */
/* Dave MacLeod <davmac@bigfoot.com>                     */
/* ----------------------------------------------------- */
/* v0.1     02/06/97    Creation                         */
/* ----------------------------------------------------- */

#pragma pack(2)
#include <System/SysAll.h>
#include <UI/UIAll.h>

#define MainForm   1000
#define fldSize    1001
#define fldWrdCnt  1002
#define fldContent 1003

/* ------------------------------------------------------ */
/* If the parameter is a blank character then return true */
/* ------------------------------------------------------ */

static Boolean IsBlank(int parmText)
{
  return (parmText == ' ' || parmText == '-' || parmText == '\t' || parmText == '\n' ) ;
}

/* ----------------------------------------------------- */
/* Display the contents of the clipboard and the length  */
/* of the clipboard contents                             */
/* ----------------------------------------------------- */

static void PasteIn()
{
  FormPtr  frmP;
  FieldPtr dstP;
  CharPtr  dstT;
  VoidHand dstHandle;
  Char     LenT[6],
           WrdCntT[6],
           ClipBrd[10240],
           Spce[1] = " ";
  int      WrdCnt,i;
  Boolean  InWord;

  /* Get pointer to active form */
  frmP = FrmGetActiveForm();

  /* Get pointer to the field which will hold the clipboard contents */
  dstP = (FieldPtr)(FrmGetObjectPtr(frmP, (FrmGetObjectIndex(frmP, fldContent))));

  /* Copy the clipboard into the screen object (also displays it) */
  FldPaste(dstP);

  /* If clipboard is empty, then length is zero, otherwise calculate length of the field we've just pasted out */
  if (FldGetTextPtr(dstP)==NULL)
  {
    StrIToA(LenT,0);
    StrIToA(WrdCntT,0);
  }
  else
  {
    WrdCnt = 0;
    InWord = false;
    StrCopy(ClipBrd,FldGetTextPtr(dstP));
    StrIToA(LenT,StrLen(ClipBrd));
    for (i=1;i<StrLen(ClipBrd);i++)
    {
      if (IsBlank(ClipBrd[i]))
        InWord = false ;
      else
        if (!InWord)
        {
	    ++WrdCnt ;
	    InWord = true ;
	  }
    }
    StrIToA(WrdCntT,WrdCnt);
  }

  /* Get pointer to the field which will hold the clipboard size */
  dstP = (FieldPtr)(FrmGetObjectPtr(frmP, (FrmGetObjectIndex(frmP, fldSize))));

  /* Allocate and lock the destination for the clipboard size */
  dstHandle = MemHandleNew(StrLen(LenT)+1);
  dstT = MemHandleLock(dstHandle);

  /* Move the string in, unlock it and repaint the field */
  StrCopy(dstT, LenT);
  MemHandleUnlock(dstHandle);
  FldSetTextHandle(dstP, (Handle)dstHandle);
  FldDrawField(dstP);

  /* Get pointer to the field which will hold the clipboard word count */
  dstP = (FieldPtr)(FrmGetObjectPtr(frmP, (FrmGetObjectIndex(frmP, fldWrdCnt))));

  /* Allocate and lock the destination for the clipboard word count */
  dstHandle = MemHandleNew(StrLen(WrdCntT)+1);
  dstT = MemHandleLock(dstHandle);

  /* Move the string in, unlock it and repaint the field */
  StrCopy(dstT, WrdCntT);
  MemHandleUnlock(dstHandle);
  FldSetTextHandle(dstP, (Handle)dstHandle);
  FldDrawField(dstP);
}

DWord PilotMain(Word cmd, Ptr cmdPBP, Word launchFlags)
{
  short err;
  EventType e;
  ClipboardFormatType clipType;
  WordPtr clipLen;
  VoidHand clipHandle;

  if (!cmd)
  {
    FrmGotoForm(MainForm);
    while(1)
    {
      EvtGetEvent(&e, 100);
      if (SysHandleEvent(&e)) continue;
      if (MenuHandleEvent((void *)0, &e, &err)) continue;
      switch (e.eType)
      {
        case frmLoadEvent:
          FrmSetActiveForm(FrmInitForm(e.data.frmLoad.formID));
          break;
        case frmOpenEvent:
          FrmDrawForm(FrmGetActiveForm());
          PasteIn();
          break;
        case appStopEvent:
          return 0;
        default:
          FrmHandleEvent(FrmGetActiveForm(), &e);
      }
    }
  }
}
